Module agent

Module agent 

Structs

AgentFile
The AgentForge native agent file schema (v1). Also the normalized representation after parsing any supported format.
AgentVersion
Parsed and versioned agent file stored in the database.
EvalHints
LintError
Lint error surfaced during agent file validation.
ModelConfig
ToolDefinition

Enums

AgentFileFormat
Supported agent file input formats.
LintSeverity
ModelProvider