Structs
- Agent
File - The AgentForge native agent file schema (v1). Also the normalized representation after parsing any supported format.
- Agent
Version - Parsed and versioned agent file stored in the database.
- Eval
Hints - Lint
Error - Lint error surfaced during agent file validation.
- Model
Config - Tool
Definition
Enums
- Agent
File Format - Supported agent file input formats.
- Lint
Severity - Model
Provider