pub struct EvalRun {Show 22 fields
pub id: Uuid,
pub agent_id: Uuid,
pub scenario_set_id: Option<Uuid>,
pub status: EvalRunStatus,
pub scenario_count: u32,
pub completed_count: u32,
pub error_count: u32,
pub aggregate_score: Option<f64>,
pub pass_rate: Option<f64>,
pub scores: Option<DimensionScores>,
pub failure_clusters: Option<Vec<FailureClusterSummary>>,
pub seed: u32,
pub concurrency: u32,
pub error_message: Option<String>,
pub started_at: Option<DateTime<Utc>>,
pub completed_at: Option<DateTime<Utc>>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub opt_status: Option<String>,
pub opt_rounds: i32,
pub opt_best_score: Option<f64>,
pub opt_best_agent_id: Option<Uuid>,
}Expand description
An evaluation run of an agent version against a scenario set.
Fields
id: Uuidagent_id: Uuidscenario_set_id: Option<Uuid>status: EvalRunStatusscenario_count: u32completed_count: u32error_count: u32aggregate_score: Option<f64>pass_rate: Option<f64>scores: Option<DimensionScores>failure_clusters: Option<Vec<FailureClusterSummary>>seed: u32concurrency: u32error_message: Option<String>started_at: Option<DateTime<Utc>>completed_at: Option<DateTime<Utc>>created_at: DateTime<Utc>updated_at: DateTime<Utc>opt_status: Option<String>Optimization loop state: running | converged | no_improvement |
max_iterations | failed. None means optimization was not requested.
opt_rounds: i32Number of completed optimization rounds (0 = not started).
opt_best_score: Option<f64>Best aggregate score achieved across all optimization rounds.
opt_best_agent_id: Option<Uuid>UUID of the best agent version saved during the optimization loop.
Implementations